
.calendar-calendar .week-view #multi-day-container,
.calendar-calendar .week-view #single-day-container,
.calendar-calendar .day-view #multi-day-container,
.calendar-calendar .day-view #single-day-container {
  overflow-y: hidden;
  overflow-x: hidden;
}
 .calendar-calendar .week-view #single-day-container,
 .calendar-calendar .day-view #single-day-container {
  height: auto;
}